package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.MultiLayerMarkerSymbol;
import com.esri.arcgis.display.ArrowMarkerSymbol;
import com.esri.arcgis.display.CharacterMarkerSymbol;
import com.esri.arcgis.display.IColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads multi layer marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class MultiLayerMarkerSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(MultiLayerMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private MultiLayerMarkerSymbol symbol;
    private MapToXMLUtils util;


    public MultiLayerMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof MultiLayerMarkerSymbol) {
            this.symbol = (MultiLayerMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a MultiLayerMarkerSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        for(int i = 0; i < symbol.getLayerCount(); i++) {
            try {
                ISymbol sym = (ISymbol)symbol.getLayer(i);

                if(sym instanceof ArrowMarkerSymbol) {
                    ISymbolReader sreader = new ArrowMarkerSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                if(sym instanceof CharacterMarkerSymbol) {
                    ISymbolReader sreader = new CharacterMarkerSymbolReader(sym);
                    sreader.setParent(renderer);
                    sreader.setUtil(util);
                    sreader.read();
                }
                else {
                    System.out.println(
                            "No known instance: " + sym.getClass().toString());
                }
            }
            catch(Exception e) {
                e.printStackTrace();
            }
        }
        return renderer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
